<?php
/**
 * Workout Lite Theme Customizer
 *
 * @package Workout Lite 
*/

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function workout_lite_customize_register( $wp_customize ) {
	
	function workout_lite_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}
	
	$wp_customize->get_setting( 'blogname' )->tranport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->tranport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
	    'selector' => 'h1.site-title',
	    'render_callback' => 'workout_lite_customize_partial_blogname',
	) );

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
	    'selector' => 'p.site-description',
	    'render_callback' => 'workout_lite_customize_partial_blogdescription',
	) );
	
	/***************************************
	** Color Scheme
	***************************************/
	$wp_customize->add_setting('color_scheme', array(
		'default' => '#d83030',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_scheme',array(
			'label' => __('Color Scheme','workout-lite'),
			'description' => __('Select theme main color from here.','workout-lite'),
			'section' => 'colors',
			'settings' => 'color_scheme'
		))
	);
	
	$wp_customize->add_setting('sub_color_scheme', array(
		'default' => '#161616',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'sub_color_scheme',array(
			'label' => __('Sub Color Scheme','workout-lite'),
			'description' => __('Select theme sub color from here.','workout-lite'),
			'section' => 'colors',
			'settings' => 'sub_color_scheme'
		))
	);

	$wp_customize->add_setting('work_headerbg_color', array(
		'default' => '#161616',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'work_headerbg_color',array(
			'label' => __('Header Background color','workout-lite'),
			'description'	=> __('Select background color for header.','workout-lite'),
			'section' => 'colors',
			'settings' => 'work_headerbg_color'
		))
	);

	$wp_customize->add_setting('work_footer_color', array(
		'default' => '#10151A',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'work_footer_color',array(
			'label' => __('Footer Background Color','workout-lite'),
			'description' => __('Select background color for footer.','workout-lite'),
			'section' => 'colors',
			'settings' => 'work_footer_color'
		))
	);

	/***************************************
	** Registerd Theme Setup Panel
	***************************************/
	$wp_customize->add_panel( 'work_theme_panel',
		array(
			'title'            => __( 'Theme Setup', 'workout-lite' ),
			'description'      => __( 'Theme Modifications like color scheme, header info, slider and sections can be done here', 'workout-lite' ),
		)
	);
	
	/***************************************
	** Slider Section
	***************************************/
	$wp_customize->add_section(
		'work_theme_slider',
		array(
			'title' => __('Theme Slider', 'workout-lite'),
			'priority' => null,
			'description'	=> __('Recommended image size (1600x900). Slider will work only when you select the static front page.','workout-lite'),
			'panel' => 'work_theme_panel',
		)
	);

	$wp_customize->add_setting('slide1',array(
			'default' => '0',
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide1',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide one:','workout-lite'),
			'section'	=> 'work_theme_slider'
	));

	$wp_customize->add_setting('slide2',array(
			'default' => '0',
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide2',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide two:','workout-lite'),
			'section'	=> 'work_theme_slider'
	));

	$wp_customize->add_setting('slide3',array(
			'default' => '0',
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide3',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide three:','workout-lite'),
			'section'	=> 'work_theme_slider'
	));

	$wp_customize->add_setting('slide_more',array(
		'default'	=> __('Read More','workout-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('slide_more',array(
		'label'	=> __('Add slider link button text.','workout-lite'),
		'section'	=> 'work_theme_slider',
		'setting'	=> 'slide_more',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('work_hide_slider',array(
		'default' => true,
		'sanitize_callback' => 'workout_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	)); 

	$wp_customize->add_control( 'work_hide_slider', array(
	   'settings' => 'work_hide_slider',
	   'section'   => 'work_theme_slider',
	   'label'     => __('Check this to hide slider.','workout-lite'),
	   'type'      => 'checkbox'
	));

	/***************************************
	** Contact Info Strip
	***************************************/
	$wp_customize->add_section(
		'work_con_strp',
		array(
			'title' => __('Contact Information Strip', 'workout-lite'),
			'priority' => null,
			'description'	=> __('Add contact information here.','workout-lite'),
			'panel' => 'work_theme_panel',
		)
	);
	
	$wp_customize->add_setting('constrpadd',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('constrpadd',array(
		'type'	=> 'text',
		'label'	=> __('Add address here','workout-lite'),
		'section'	=> 'work_con_strp'
	));
	
	$wp_customize->add_setting('constrpmail',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('constrpmail',array(
		'type'	=> 'text',
		'label'	=> __('Add email address here','workout-lite'),
		'section'	=> 'work_con_strp'
	));
	
	$wp_customize->add_setting('constrpphn',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('constrpphn',array(
		'type'	=> 'text',
		'label'	=> __('Add phone number here','workout-lite'),
		'section'	=> 'work_con_strp'
	));

	$wp_customize->add_setting('con_strp_fb',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('con_strp_fb',array(
		'type'	=> 'text',
		'label'	=> __('Add facebook account link here','workout-lite'),
		'section'	=> 'work_con_strp'
	));
	
	$wp_customize->add_setting('con_strp_tw',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('con_strp_tw',array(
		'type'	=> 'text',
		'label'	=> __('Add twitter account link here','workout-lite'),
		'section'	=> 'work_con_strp'
	));
	
	$wp_customize->add_setting('con_strp_ins',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('con_strp_ins',array(
		'type'	=> 'text',
		'label'	=> __('Add instagram account link here','workout-lite'),
		'section'	=> 'work_con_strp'
	));
	
	$wp_customize->add_setting('con_strp_pin',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('con_strp_pin',array(
		'type'	=> 'text',
		'label'	=> __('Add pinterest account link here','workout-lite'),
		'section'	=> 'work_con_strp'
	));
	
	$wp_customize->add_setting('con_strp_yt',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('con_strp_yt',array(
		'type'	=> 'text',
		'label'	=> __('Add youtube account link here','workout-lite'),
		'section'	=> 'work_con_strp'
	));
	
	$wp_customize->selective_refresh->add_partial('constrpadd', array(
        'selector' => '.getintouch'
    ));
	
	$wp_customize->add_setting('hide_con_strp',array(
		'default' => true,
		'sanitize_callback' => 'workout_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'hide_con_strp', array(
	   'settings' => 'hide_con_strp',
	   'section'   => 'work_con_strp',
	   'label'     => __('Check this to hide contact information.','workout-lite'),
	   'type'      => 'checkbox'
	));
	
	/***************************************
	** Features Section
	***************************************/
	$wp_customize->add_section(
		'work_feat_sec',
		array(
			'title' => __('Features Section', 'workout-lite'),
			'priority' => null,
			'description'	=> __('Select pages for homepage second section. This section will be displayed only when you select the static front page.','workout-lite'),
			'panel' => 'work_theme_panel',
		)
	);

	$wp_customize->add_setting('feat1',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('feat1',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for first column','workout-lite'),
		'section'	=> 'work_feat_sec'
	));

	$wp_customize->add_setting('feat2',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('feat2',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for second column','workout-lite'),
		'section'	=> 'work_feat_sec'
	));

	$wp_customize->add_setting('feat3',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('feat3',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for third column','workout-lite'),
		'section'	=> 'work_feat_sec'
	));

	$wp_customize->add_setting('feat4',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('feat4',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for fourth column','workout-lite'),
		'section'	=> 'work_feat_sec'
	));

	$wp_customize->add_setting('work_hide_feat',array(
		'default' => true,
		'sanitize_callback' => 'workout_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'work_hide_feat', array(
	   'settings' => 'work_hide_feat',
	   'section'   => 'work_feat_sec',
	   'label'     => __('Check this to hide features section.','workout-lite'),
	   'type'      => 'checkbox'
	));

	/***************************************
	** About Section
	***************************************/
	$wp_customize->add_section(
		'work_intro_sec',
		array(
			'title' => __('About us Section', 'workout-lite'),
			'priority' => null,
			'description'	=> __('Select page for homepage first section. This section will be displayed only when you select the static front page.','workout-lite'),
			'panel' => 'work_theme_panel',
		)
	);
	
	$wp_customize->add_setting('work_intro_ttl',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('work_intro_ttl',array(
		'type'	=> 'text',
		'label'	=> __('Add Section Sub Title Here','workout-lite'),
		'section'	=> 'work_intro_sec'
	));
	
	$wp_customize->add_setting('work_intro',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('work_intro',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for display first section','workout-lite'),
		'section'	=> 'work_intro_sec'
	));
	
	$wp_customize->selective_refresh->add_partial('work_intro', array(
        'selector' => '.intro-content'
    ));
	
	$wp_customize->add_setting('intro_more',array(
		'default'	=> __('Read More','workout-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('intro_more',array(
		'label'	=> __('Add read more button text.','workout-lite'),
		'section'	=> 'work_intro_sec',
		'setting'	=> 'intro_more',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('work_hide_intro',array(
		'default' => true,
		'sanitize_callback' => 'workout_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'work_hide_intro', array(
	   'settings' => 'work_hide_intro',
	   'section'   => 'work_intro_sec',
	   'label'     => __('Check this to hide first section.','workout-lite'),
	   'type'      => 'checkbox'
	));
}
add_action( 'customize_register', 'workout_lite_customize_register' );

function workout_lite_css_func(){ ?>
<style>
	#header{
		background-color:<?php echo esc_attr(get_theme_mod('work_headerbg_color','#161616')); ?>;
	}
	a,
	.tm_client strong,
	.postmeta a:hover,
	.blog-post h3.entry-title,
	a.blog-more:hover,
	#commentform input#submit,
	input.search-submit,
	.blog-date .date,
	.sitenav ul li.current_page_item a,
	.sitenav ul li a:hover,
	.sitenav ul li.current_page_item ul li a:hover,
	p.site-description,
	h4.section_sub_title{
		color:<?php echo esc_attr(get_theme_mod('color_scheme','#d83030'));?>;
	}
	h3.widget-title,
	.nav-links .current,
	.nav-links a:hover,
	p.form-submit input[type="submit"],
	.nivo-controlNav a,
	.work-slider .inner-caption .sliderbtn,
	.read-more a,
	.getintouch,
	.introduction .thumb:before,
	.feature-box:hover .feature-more a,
	.feature-box:after{
		background-color:<?php echo esc_attr(get_theme_mod('color_scheme','#d83030')); ?>;
	}
	a:hover,
	#sidebar ul li a:hover,
	h2.section_title{
		color:<?php echo esc_attr(get_theme_mod('sub_color_scheme','#161616')); ?>;
	}
	#navigation,
	.sitenav ul li.menu-item-has-children:hover > ul,
	.sitenav ul li.menu-item-has-children:focus > ul,
	.sitenav ul li.menu-item-has-children.focus > ul,
	.work-slider .inner-caption .sliderbtn:hover,
	.read-more a:hover,
	.nivo-controlNav a.active,
	.getintouch ul li:not(:nth-of-type(2n)),
	.feature-more a{
		background-color:<?php echo esc_attr(get_theme_mod('sub_color_scheme','#161616')); ?>;
	}
	.copyright-wrapper{
		background-color:<?php echo esc_attr(get_theme_mod('work_footer_color','#10151A')); ?>;
	}
</style>
<?php }
add_action('wp_head','workout_lite_css_func');

function workout_lite_customize_preview_js() {
	wp_enqueue_script( 'workout-lite-customize-preview', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20141216', true );
}
add_action( 'customize_preview_init', 'workout_lite_customize_preview_js' );